//@line 36 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/extensions/newsblog/content/am-newsblog.js"

var gIncomingServer;

function onInit() 
{  
  // set our custom quickMode attribute
  document.getElementById('useQuickMode').checked = gIncomingServer.getBoolAttribute("quickMode");
}

function onPreInit(account, accountValues)
{
  gIncomingServer = account.incomingServer;
}

function onSave()
{
  gIncomingServer.setBoolAttribute("quickMode", document.getElementById('useQuickMode').checked);
}

function manageSubscriptions()
{
  // XXX: This code should be shared with the JS in toolbar-icon.xul
  const kWindowMediatorContractID = "@mozilla.org/appshell/window-mediator;1";
  const kWindowMediatorIID = Components.interfaces.nsIWindowMediator;
  const kWindowMediator = Components.classes[kWindowMediatorContractID].getService(kWindowMediatorIID);
  var lastSubscriptionWindow = kWindowMediator.getMostRecentWindow("Mail:News-BlogSubscriptions");

  if (lastSubscriptionWindow)
    lastSubscriptionWindow.focus();
  else 
    window.openDialog("chrome://messenger-newsblog/content/feed-subscriptions.xul", "",
                      "centerscreen,chrome,dialog=no,resizable", { server: gIncomingServer});
}
